@@ -1,19 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 
-import os
-
-base_url = os.environ.get('DOC_BASE_URL')
-if base_url:
-    modules_url = base_url + '/modules-{module}/'
-    trytond_url = base_url + '/server/'
-else:
-    modules_url = (
-        'https://docs.tryton.org/projects/modules-{module}/en/{series}/')
-    trytond_url = 'https://docs.tryton.org/projects/server/en/{series}/'
+modules_url = 'https://docs.tryton.org/projects/modules-{module}/en/{series}/'
+trytond_url = 'https://docs.tryton.org/projects/server/en/{series}/'
 
 
 def get_info():
+    import os
     import subprocess
     import sys
 
@@ -49,9 +42,7 @@ extensions = [
     'sphinx.ext.intersphinx',
     ]
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/', None),
     'trytond': (trytond_url.format(series=version), None),
     }
-linkcheck_ignore = [r'/.*', r'https://demo.tryton.org/*']
 
-del get_info, info, base_url, modules_url, trytond_url
+del get_info, info, modules_url, trytond_url
