@@ -1,9 +1,11 @@
 # This file is part of trytond_gis.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.backend.postgresql.database import (
-    DatabaseIntegrityError, DatabaseOperationalError)
+    DatabaseDataError, DatabaseIntegrityError, DatabaseOperationalError)
+
 from .database import Database
 from .table import TableHandler
 
 __all__ = [
-    Database, DatabaseIntegrityError, DatabaseOperationalError, TableHandler]
+    Database, TableHandler,
+    DatabaseIntegrityError, DatabaseDataError, DatabaseOperationalError]
